==> landers.angular-1.0.92.tgz: package/src/utils/factory-flat.js <==
;angular.module('Landers.angular')
    .factory('Flat', function () {
        function Flat(scope, J){
            var that = Flat;
            this.apply = function(){
                if (!scope.$$phase) scope.$apply();
                return this;
            };
            this.get = function(key, subkey) {
                return that.get(J, key, subkey);
            };
            this.pull = function(key) {
                var ret = that.pull(J, key);
                this.apply();
                return ret;
            };
            this.set = function(key, value, subkey){
                that.set(J, key, value, subkey);
                return this.apply();
            };
            this.setOnce = function(key, value, subkey){
                var ret = that.setOnce(J, key, value, subkey);
                this.apply();
                return ret;
            };
            this.delete = function(key) {
                that.delete(J, key);
                return this.apply();
            };
            this.clear = function(){
                that.clear(J);
                return this.apply();
            };
            this.extend = function(json, subkey){
                that.extend(J, json, subkey);
                return this.apply();
            };
            this.cut = function(key, index) {
                that.cut(J, key, index);
                return this.apply();
            };
            this.copy = function(key, start, end) {
                that.copy(J, key, start, end);
                return this.apply();
            };
            this.shift = function(key) {
                that.shift(J, key);
                return this.apply();
            };
            this.unshift = function(key, value) {
                that.unshift(J, key, value);
                return this.apply();
            };
            this.push = function(key, value){
                that.push(J, key, value);
                return this.apply();
            };
            this.pop = function(key) {
                that.pop(J, key);
                return this.apply();
            };
        }
        angular.extend(Flat, {
            make : function(scope, J) {
                return new Flat(scope, J);
            },
            parse : function(J, key, subkey){
                if (subkey !== null && subkey !== undefined && subkey !== '') key += '.' + subkey;
                var a = key.split('.');
                J = J || {};
                if (a.length == 1) {
                    return {
                        obj:J, key:key
                    };
                } else {
                    for (var i=0; i<a.length-1; i++) {
                        J = J || {};
                        if ( ! (a[i] in J) ) {
                            J[a[i]] = {};
                        }
                        J[a[i]] = J[a[i]] || {};
                        J = J[a[i]];
                    }
                    return {
                        obj:J,
                        key:a[i]
                    };
                }
            },
            get : function(J, key, subkey) {
                var parse = this.parse(J, key, subkey);
                return parse.obj[parse.key];
            },
            pull : function(J, key){
                var ret = this.get(J, key);
                this.delete(J, key);
                return ret;
            },
            set : function(J, key, value, subkey){
                var parse = this.parse(J, key, subkey);
                // parse.obj = parse.obj || {}; //promote 为空时
                parse.obj[parse.key] = value;
                return this;
            },
            setOnce : function(J, key, value, subkey){
                var ret = this.get(J, key, subkey);
                if ( ret ) return ret;
                this.set(J, key, value, subkey);
                return value;
            },
            delete : function(J, key) {
                var parse = this.parse(J, key);
                delete parse.obj[parse.key];
                return this;
            },
            clear : function(J) {
                for (var k in J) delete J[k];
                J = {};
                return this;
            },
            extend : function(J, jdat, subkey) {
                if (subkey) {
                    var value = this.get(J, subkey) || {};
                    angular.extend(value, jdat);
                    this.set(J, subkey, value);
                } else {
                    for (var key in jdat) {
                        this.set(J, key, jdat[key]);
                    }
                }
                return this;
            },
            cut : function(J, key, index) {
                var parse = this.parse(J, key);
                parse.obj[parse.key].splice(index, 1);
                return parse.obj[parse.key];
            },
            copy : function(J, key, start, end) {
                var parse = this.parse(J, key);
                return parse.obj[parse.key].slice(start);
            },
            shift : function(J, key) {
                var parse = this.parse(J, key);
                parse.obj[parse.key].shift();
                return this;
            },
            unshift : function(J, key, value) {
                var parse = this.parse(J, key);
                try {
                    parse.obj[parse.key].unshift(value);
                }catch(e){
                    console.log(J);
                    console.log(key);
                    console.log(value);
                }
                return this;
            },
            push : function(J, key, value){
                var parse = this.parse(J, key);
                parse.obj[parse.key] = parse.obj[parse.key] || [];
                parse.obj[parse.key].push(value);
                return this;
            },
            pop : function(J, key) {
                var parse = this.parse(J, key);
                parse.obj[parse.key].pop();
                return this;
            }
        });

        return Flat;
    });

==> landers.angular-2.0.24.tgz: package/src/utils/factory-flat.js <==
;angular.module('Landers.angular')
    .factory('Flat', function () {
        function Flat(scope, J){
            var that = Flat;
            this.apply = function(){
                if (!scope.$$phase) scope.$apply();
                return this;
            };
            this.get = function(key, subkey) {
                return that.get(J, key, subkey);
            };
            this.pull = function(key) {
                var ret = that.pull(J, key);
                this.apply();
                return ret;
            };
            this.set = function(key, value, subkey){
                that.set(J, key, value, subkey);
                return this.apply();
            };
            this.setOnce = function(key, value, subkey){
                var ret = that.setOnce(J, key, value, subkey);
                this.apply();
                return ret;
            };
            this.delete = function(key) {
                that.delete(J, key);
                return this.apply();
            };
            this.clear = function(){
                that.clear(J);
                return this.apply();
            };
            this.extend = function(json, subkey){
                that.extend(J, json, subkey);
                return this.apply();
            };
            this.cut = function(key, index) {
                that.cut(J, key, index);
                return this.apply();
            };
            this.copy = function(key, start, end) {
                that.copy(J, key, start, end);
                return this.apply();
            };
            this.shift = function(key) {
                that.shift(J, key);
                return this.apply();
            };
            this.unshift = function(key, value) {
                that.unshift(J, key, value);
                return this.apply();
            };
            this.push = function(key, value){
                that.push(J, key, value);
                return this.apply();
            };
            this.pop = function(key) {
                that.pop(J, key);
                return this.apply();
            };
        }
        angular.extend(Flat, {
            make : function(scope, J) {
                return new Flat(scope, J);
            },
            parse : function(J, key, subkey){
                if (subkey !== null && subkey !== undefined && subkey !== '') key += '.' + subkey;
                var a = key.split('.');
                J = J || {};
                if (a.length == 1) {
                    return {
                        obj:J, key:key
                    };
                } else {
                    for (var i=0; i<a.length-1; i++) {
                        J = J || {};
                        if ( ! (a[i] in J) ) {
                            J[a[i]] = {};
                        }
                        J[a[i]] = J[a[i]] || {};
                        J = J[a[i]];
                    }
                    return {
                        obj:J,
                        key:a[i]
                    };
                }
            },
            get : function(J, key, subkey) {
                var parse = this.parse(J, key, subkey);
                return parse.obj[parse.key];
            },
            pull : function(J, key){
                var ret = this.get(J, key);
                this.delete(J, key);
                return ret;
            },
            set : function(J, key, value, subkey){
                var parse = this.parse(J, key, subkey);
                // parse.obj = parse.obj || {}; //promote 为空时
                parse.obj[parse.key] = value;
                return this;
            },
            setOnce : function(J, key, value, subkey){
                var ret = this.get(J, key, subkey);
                if ( ret ) return ret;
                this.set(J, key, value, subkey);
                return value;
            },
            delete : function(J, key) {
                var parse = this.parse(J, key);
                delete parse.obj[parse.key];
                return this;
            },
            clear : function(J) {
                for (var k in J) delete J[k];
                J = {};
                return this;
            },
            extend : function(J, jdat, subkey) {
                if (subkey) {
                    var value = this.get(J, subkey) || {};
                    angular.extend(value, jdat);
                    this.set(J, subkey, value);
                } else {
                    for (var key in jdat) {
                        this.set(J, key, jdat[key]);
                    }
                }
                return this;
            },
            cut : function(J, key, index) {
                var parse = this.parse(J, key);
                parse.obj[parse.key].splice(index, 1);
                return parse.obj[parse.key];
            },
            copy : function(J, key, start, end) {
                var parse = this.parse(J, key);
                console.log(parse.obj);
                return parse.obj[parse.key].slice(start, end);
            },
            shift : function(J, key) {
                var parse = this.parse(J, key);
                parse.obj[parse.key].shift();
                return this;
            },
            unshift : function(J, key, value) {
                var parse = this.parse(J, key);
                try {
                    parse.obj[parse.key].unshift(value);
                }catch(e){
                    console.log(J);
                    console.log(key);
                    console.log(value);
                }
                return this;
            },
            push : function(J, key, value){
                var parse = this.parse(J, key);
                parse.obj[parse.key] = parse.obj[parse.key] || [];
                parse.obj[parse.key].push(value);
                return this;
            },
            pop : function(J, key) {
                var parse = this.parse(J, key);
                parse.obj[parse.key].pop();
                return this;
            }
        });

        return Flat;
    });
